@@ -1,11 +1,119 @@
 package App::Git::Info;
-$App::Git::Info::VERSION = '0.6.1';
+$App::Git::Info::VERSION = '0.8.0';
 use strict;
 use warnings;
 use 5.016;
 use autodie;
 
-use App::Cmd::Setup -app;
+sub new
+{
+    my $class = shift;
+
+    my $self = bless {}, $class;
+
+    $self->_init(@_);
+
+    return $self;
+}
+
+sub _argv
+{
+    my $self = shift;
+
+    if (@_)
+    {
+        $self->{_argv} = shift;
+    }
+
+    return $self->{_argv};
+}
+
+sub _init
+{
+    my ( $self, $args ) = @_;
+
+    my $argv = $args->{argv} or die "specify argv";
+
+    $self->_argv( [ @{$argv} ] );
+
+    return;
+}
+
+sub _abstract
+{
+    return "Displays a summary of information about the git repository.";
+}
+
+sub _description { return _abstract(); }
+
+sub _opt_spec
+{
+    return ();
+}
+
+sub _validate_args
+{
+    my ( $self, $opt, $args ) = @_;
+
+    # no args allowed but options!
+    $self->usage_error("No args allowed") if @$args;
+
+    return;
+}
+
+sub _execute
+{
+    my ( $self, $opt, $args ) = @_;
+
+    my $ST = `git status`;
+    if ($?)
+    {
+        return;
+    }
+
+    my $ret =
+        ( $ST =~
+s#\A(On branch \S+\n)((?:\S[^\n]*\n)?).*#"⇒ $1".($2 ? "⇒ $2" : "")#emrs
+            . `git status -s`
+            . "⇒ Remotes:\n"
+            . `git remote -v` );
+    chomp $ret;
+    say $ret;
+
+    return;
+}
+
+sub run
+{
+    my $self = shift;
+    my $argv = [ @{ $self->_argv() } ];
+
+    if ( not @$argv )
+    {
+        die
+qq#Must include a verb/action command - e.g "git-info info" or "git-info help"#;
+    }
+
+    my $cmd = shift @$argv;
+
+    if ( $cmd eq "info" )
+    {
+        return $self->_execute( undef(), $argv, );
+    }
+    elsif ( $cmd eq "help" )
+    {
+        print <<'ENDOFHELP';
+git-info info - Displays a summary of information about the git repository.
+
+ENDOFHELP
+    }
+    else
+    {
+        die "must be git-info info!";
+    }
+}
+
+1;
 
 __END__
 
@@ -19,7 +127,7 @@ App::Git::Info - Displays a summary of information about the git repository.
 
 =head1 VERSION
 
-version 0.6.1
+version 0.8.0
 
 =head1 SYNOPSIS
 
@@ -37,6 +145,16 @@ version 0.6.1
 Displays a git dashboard-of-sorts with info from C<git status>,
 C<git status -s>, and C<git remote -v> .
 
+=head1 METHODS
+
+=head2 my $app = App::Git::Info->new({ argv => [@ARGV], })
+
+Create a git-info app.
+
+=head2 $app->run()
+
+Run the git-info app.
+
 =for :stopwords cpan testmatrix url bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
 
 =head1 SUPPORT
